use v6-alpha;

use Foo;

class Bar is ::Foo;

method bar { "bar" }

